<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	
	<xsl:import href="CommonTemplates.xsl"/>

	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />


	<!-- Process Summary Section -->
	<xsl:template match="optimreport:summary[@*] | optimreport:archiveFileReport | optimreport:compareFileReport | optimreport:securityReport | optimreport:archiveDirectoryReport">
		<xsl:param name="display">True</xsl:param>
		
		<xsl:variable name="displayStyle">
			<xsl:choose>
				<xsl:when test="$display='True'">
					<xsl:text></xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>display:none</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procsum</xsl:with-param>
		</xsl:call-template>
		<!-- Report Summary Banner -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Summary</xsl:with-param>
			<xsl:with-param name="containerId">summary_container</xsl:with-param>
			<xsl:with-param name="containerClass">summary_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procsum</xsl:with-param>
			<xsl:with-param name="closeByDefault">
				<xsl:choose>
					<xsl:when test="$display='True'">
						<xsl:text>false</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>true</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
		
		<!-- Report Summary Contents -->
		<div id="summary_container" class="section_container summary_container_class" style="{$displayStyle}" inAllAction="true">
			<!--BEGIN SUMMARY TABLE-->
			<xsl:choose>
				<xsl:when test="contains(name(.), 'securityReport')">
					<xsl:call-template name="security_summary"/>
				</xsl:when>
				<xsl:when test="contains(name(.), 'archiveDirectoryReport')">
					<xsl:call-template name="directory_summary"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="tablesForSummary"/>
				</xsl:otherwise>
			</xsl:choose>
			<!--END SUMMARY TABLE-->

			<!-- Determine if we have any messages at all -->
			<xsl:if test="../*/optimcommon:message">
				<div id="process_msg_container">
					<div class="messageCatalogBoard" style="display:none;">
						<div class="arrowContainer">
							<div class="imageArrow"/>
						</div>
						<div class="messageContent" />
					</div>
					
					<!--Trying to match message collections-->
					<xsl:apply-templates select="../optimreport:errorMessages">
						<xsl:with-param name="anchor">error_msg_box</xsl:with-param>
						<xsl:with-param name="classname">error_msg_class</xsl:with-param>
						<xsl:with-param name="arrowid">error_msg_arrow</xsl:with-param>
						<xsl:with-param name="id">error_msg_id</xsl:with-param>
						<xsl:with-param name="isExpand">true</xsl:with-param>
						<xsl:with-param name="boardName">Error Messages</xsl:with-param>
					</xsl:apply-templates>
					<xsl:apply-templates select="../optimreport:warningMessages">
						<xsl:with-param name="anchor">warn_msg_box</xsl:with-param>
						<xsl:with-param name="classname">warning_msg_class</xsl:with-param>
						<xsl:with-param name="arrowid">warning_msg_arrow</xsl:with-param>
						<xsl:with-param name="id">warning_msg_id</xsl:with-param>
						<xsl:with-param name="isExpand">false</xsl:with-param>
						<xsl:with-param name="boardName">Warning Messages</xsl:with-param>
					</xsl:apply-templates>
					<xsl:apply-templates select="../optimreport:informationMessages">
						<xsl:with-param name="anchor">info_msg_box</xsl:with-param>
						<xsl:with-param name="classname">info_msg_class</xsl:with-param>
						<xsl:with-param name="arrowid">info_msg_arrow</xsl:with-param>
						<xsl:with-param name="id">info_msg_id</xsl:with-param>
						<xsl:with-param name="isExpand">false</xsl:with-param>
						<xsl:with-param name="boardName">Informational Messages</xsl:with-param>
					</xsl:apply-templates>
					<xsl:apply-templates select="../optimreport:exitMessages">
						<xsl:with-param name="anchor">exit_msg_box</xsl:with-param>
						<xsl:with-param name="classname">exit_msg_class</xsl:with-param>
						<xsl:with-param name="arrowid">exit_msg_arrow</xsl:with-param>
						<xsl:with-param name="id">exit_msg_id</xsl:with-param>
						<xsl:with-param name="isExpand">false</xsl:with-param>
						<xsl:with-param name="boardName">Exit Messages</xsl:with-param>
					</xsl:apply-templates>
				</div>
			</xsl:if>
		</div>
	</xsl:template>
	<!-- END Process Summary Section -->

	<xsl:template name="directory_summary">
		<table>
			<tr>
				<th class="second_indent">
					Auto delete
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select="@autoDelete"/>
					</xsl:call-template>
				</td>
			</tr>
			<tr>
				<th class="second_indent">
					Combine operator
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select=".//optimreport:combineOperator"/>
					</xsl:call-template>
				</td>
			</tr>
			<tr>
				<th class="second_indent">
					Entries found
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select="@entriesFound"/>
					</xsl:call-template>
				</td>
			</tr>
			<tr>
				<th class="second_indent">
					Optim directory
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select="@directoryName"/>
					</xsl:call-template>
				</td>
			</tr>
		</table>

		<table class="directory_criteria_table block_gap">
			<tr istitle="yes">
				<td  colspan="2">
					<center>
						Archive Criteria
					</center>
				</td>
			</tr>
			<tr>
				<th>
					<center>
						Name
					</center>
				</th>
				<th>
					<center>
						Value
					</center>
				</th>
			</tr>
			<xsl:for-each select="optimreport:archiveCriteria/optimreport:criteria">
				<tr>
					<td>
						<xsl:call-template name="stringCheck">
							<xsl:with-param  name="value" select="@name"/>
						</xsl:call-template>
					</td>
					<td>
						<xsl:call-template name="stringCheck">
							<xsl:with-param  name="value" select="@value"/>
						</xsl:call-template>
					</td>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>

	<xsl:template match="optimreport:objectSecurityDetail">
		<xsl:param name="aclName"/>
		<xsl:param name="userGroup"/>
		<td>
		<xsl:choose>
			<xsl:when test="*">
				<a href="{concat('#', $aclName)}" onclick="expandAfterAnchor(event)">
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select="@name"/>
					</xsl:call-template>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="stringCheck">
					<xsl:with-param name="value" select="@name"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		</td>
		<td>
			<xsl:call-template name="stringCheck">
				<xsl:with-param name="value" select="$userGroup"/>
			</xsl:call-template>
		</td>
	</xsl:template>
	
	<xsl:template name="security_summary">
		<table>
			<xsl:choose>
				<xsl:when test="contains(name(./*), 'objectReport')">
					<tr>
						<th>
							Report type
						</th>
						<td>
							Security
						</td>
					</tr>
					<tr>
						<th>
							Criteria type
						</th>
						<td>
							Object
						</td>
					</tr>
					<tr>
						<th>
							Server name
						</th>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="./*/optimreport:serverName/text()"/>
							</xsl:call-template>
						</td>
					</tr>
				</xsl:when>
				<xsl:when test="contains(name(./*), 'functionReport')">
					<tr>
						<th>
							Report type
						</th>
						<td>
							Security
						</td>
					</tr>
					<tr>
						<th>
							Criteria type
						</th>
						<td>
							Function
						</td>
					</tr>
				</xsl:when>
				<xsl:when test="contains(name(./*), 'userReport')">
					<tr>
						<th>
							Server name
						</th>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="./optimreport:userReport/optimreport:serverName/text()"/>
							</xsl:call-template>
						</td>
					</tr>
					<tr>
						<th>
							Criteria type
						</th>
						<td>
							User
						</td>
					</tr>
				</xsl:when>
			</xsl:choose>
		</table>

		<xsl:choose>
			<xsl:when test="contains(name(./*), 'objectReport')">
				<table class="block_gap">
					<tr>
						<th>
							<center>
								Object type
							</center>
						</th>
						<th>
							<center>
								Object name
							</center>
						</th>
						<th>
							<center>
								User / Group
							</center>
						</th>
					</tr>
					<xsl:for-each select="./*/optimreport:objectACL">
						<xsl:variable name="aclName" select="concat(@type, concat(' ', @name))"/>
						<tr>
							<td>
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="@type"/>
								</xsl:call-template>
							</td>
							<!-- Only set link when there is content below-->
							<xsl:apply-templates select="../optimreport:objectSecurityDetail[substring-before(@name, ':')=$aclName]">
								<xsl:with-param name="aclName" select="$aclName"/>
								<xsl:with-param name="userGroup" select="@userGroup"/>
							</xsl:apply-templates>
						</tr>
					</xsl:for-each>
				</table>
			</xsl:when>
			<xsl:when test="contains(name(./*), 'functionReport')">
				<xsl:variable name="smallcase" select="'abcdefghijklmnopqrstuvwxyz'" />
				<xsl:variable name="uppercase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'" />
				<table class="block_gap function_security_group_table">
					<tr istitle="yes">
						<td>
							<center>
								Privileges
							</center>
						</td>
					</tr>
					<xsl:for-each select="optimreport:functionReport/optimreport:privilegeCriteria[not(@privilegeClass = preceding-sibling::optimreport:privilegeCriteria/@privilegeClass)]">
						<xsl:variable name="classname" select="generate-id(.)"/>
						<tr swaparrow="true">
							<td>
								<!-- End of Javascript controls -->
								<xsl:variable name="anchor" select="$classname"/>
								<a href="{concat('#', $anchor)}" class="second_indent" onclick="expandAfterAnchor(event)">
									<xsl:value-of select="@privilegeClass"/>
								</a>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</xsl:when>
			<xsl:when test="contains(name(./*), 'userReport')">
				<xsl:call-template name="userTemplateSummary">
					<xsl:with-param name="title">User / Group</xsl:with-param>
					<xsl:with-param name="summaryNode" select="./optimreport:userReport/optimreport:userGroup"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="userTemplateSummary">
		<xsl:param name="summaryNode"/>
		<xsl:param name="title"/>
		<table class="block_gap user_security_group_table">
			<tr istitle="yes">
				<td>
					<center>
						<xsl:value-of select="$title"/>
					</center>
				</td>
			</tr>
			<xsl:for-each select="$summaryNode">
				<xsl:variable name="name" select="text()"/>
				<xsl:variable name="classname" select="generate-id(.)"/>
				<tr>
					<td class="category_title">
						<xsl:choose>
							<xsl:when test="contains(../*/@userGroup, $name)">
								<!-- Javascript controls to expand and collapse the section -->
								<a href="{concat('#', $classname)}" class="second_indent" onclick="expandAfterAnchor(event)">
									<xsl:value-of select="$name"/>
								</a>
							</xsl:when>
							<xsl:otherwise>
								<span class="second_indent">
									<xsl:value-of select="$name"/>
								</span>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</xsl:for-each>
		</table>
		
	</xsl:template>
	
</xsl:stylesheet>

